pub struct NoData { /* private fields */ }
Placeholder to hold response bodies that will be discarded.

Result<()> can’t be used with the macro return type because it expects a unit type, so a temporary struct is used.

Examples

endpoint! {
    POST "/captcha/solve",
    #[body] SolveCaptcha<'_>,
    #[discard_result] Result<NoData> // `Result<()>` results in a deserialization error despite discarding the result.
}