Struct mangadex_api_schema_rust::NoData
source · pub struct NoData { /* private fields */ }Expand description
Placeholder to hold response bodies that will be discarded.
Result<()> can’t be used with the macro return type because it expects a unit type,
so a temporary struct is used.
Examples
endpoint! {
POST "/captcha/solve",
#[body] SolveCaptcha<'_>,
#[discard_result] Result<NoData> // `Result<()>` results in a deserialization error despite discarding the result.
}Trait Implementations
sourceimpl<'de> Deserialize<'de> for NoData
impl<'de> Deserialize<'de> for NoData
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl FromResponse for NoData
impl FromResponse for NoData
sourceimpl PartialEq for NoData
impl PartialEq for NoData
impl Eq for NoData
impl StructuralEq for NoData
impl StructuralPartialEq for NoData